@@ -17,7 +17,7 @@ except BaseException as E:
     # wrapping just ImportError fails in some cases
     # will raise the error when someone tries to use KDtree
     from . import exceptions
-    cKDTree = exceptions.closure(E)
+    cKDTree = exceptions.ExceptionWrapper(E)
 
 
 def merge_vertices(mesh,
@@ -397,8 +397,9 @@ def merge_runs(data, digits=None):
     Out[2]: array([-1,  0,  1,  2,  0,  3,  4,  5,  6,  7,  8,  9])
     """
     data = np.asanyarray(data)
-    mask = np.abs(np.diff(data)) > tol.merge
-    mask = np.concatenate((np.array([True]), mask))
+    mask = np.empty(len(data), dtype=bool)
+    mask[0] = True
+    mask[1:] = np.abs(data[1:] - data[:-1]) > tol.merge
 
     return data[mask]
 
@@ -767,11 +768,18 @@ def blocks(data,
     """
     data = float_to_int(data, digits=digits)
 
-    # find the inflection points
-    # AKA locations where the array goes from True to False.
-    infl = np.concatenate((
-        [0], np.nonzero(np.diff(data))[0] + 1, [len(data)]))
-    infl_len = np.diff(infl)
+    # keep an integer range around so we can slice
+    arange = np.arange(len(data))
+    arange.flags['WRITEABLE'] = False
+
+    nonzero = arange[1:][data[1:] != data[:-1]]
+    infl = np.zeros(len(nonzero) + 2, dtype=int)
+    infl[-1] = len(data)
+    infl[1:-1] = nonzero
+
+    # the length of each chunk
+    infl_len = infl[1:] - infl[:-1]
+
     # check the length of each group
     infl_ok = np.logical_and(infl_len >= min_len,
                              infl_len <= max_len)
@@ -783,7 +791,7 @@ def blocks(data,
             infl_ok, data[infl[:-1]])
 
     # inflate start/end indexes into full ranges of values
-    blocks = [np.arange(infl[i], infl[i + 1])
+    blocks = [arange[infl[i]:infl[i + 1]]
               for i, ok in enumerate(infl_ok) if ok]
 
     if wrap:
